"""
Constants used across the Relia application.
"""

HOURS_PER_MONTH = 730
DEFAULT_EBS_SIZE_GB = 8
DEFAULT_LAMBDA_MEMORY_MB = 128
DEFAULT_LAMBDA_DURATION_MS = 100.0
DEFAULT_LAMBDA_REQUESTS = 0
DEFAULT_S3_STORAGE_GB = 0
